@@ -1,7 +1,8 @@
 import os
+from collections import defaultdict
 from enum import Enum
 from functools import lru_cache
-from typing import Type, List
+from typing import Type, List, Dict, cast
 
 from iobes import (
     parse_spans_iobes,
@@ -9,7 +10,7 @@ from iobes import (
     parse_spans_bilou,
     parse_spans_bmeow,
 )
-from pydantic import BaseModel
+from pydantic import BaseModel, Field
 from pymultirole_plugins.v1.annotator import AnnotatorParameters, AnnotatorBase
 from pymultirole_plugins.v1.schema import Document, Span, Annotation
 from trankit import Pipeline
@@ -23,6 +24,13 @@ class Embeddings(str, Enum):
     xlm_roberta_large = "xlm-roberta-large"
 
 
+class TrankitLabel(str, Enum):
+    PER = "PER"
+    MISC = "MISC"
+    LOC = "LOC"
+    ORG = "ORG"
+
+
 class TrankitNERParameters(AnnotatorParameters):
     # embeddings: Embeddings = Field(Embeddings.xlm_roberta_base,
     #                                description="""Which flavor of XLM-Roberta embeddings to use,
@@ -30,7 +38,11 @@ class TrankitNERParameters(AnnotatorParameters):
     # <li>`xlm-roberta-base`
     # <li>`xlm-roberta-large`
     # """)
-    pass
+    mapping: Dict[str, List[TrankitLabel]] = Field(
+        None,
+        description="Map a label to a list of trankit NER labels",
+        extra="key:label",
+    )
 
 
 SUPPORTED_LANGUAGES = {
@@ -54,11 +66,24 @@ class TrankitNERAnnotator(AnnotatorBase):
     def annotate(
             self, documents: List[Document], parameters: AnnotatorParameters
     ) -> List[Document]:
+
+        params: TrankitNERParameters = \
+            cast(TrankitNERParameters, parameters)
+
+        if params.mapping is not None:
+            trankit2labels = defaultdict(list)
+            for k, label_lst in params.mapping.items():
+                for label in label_lst:
+                    trankit2labels[label].append(k)
+        else:
+            trankit2labels = None
+
         for document in documents:
             # Create cached pipeline context with language and embeddigns information
             lang = document_language(document, None)
             if lang is None or lang not in SUPPORTED_LANGUAGES:
-                raise AttributeError(f"Metadata language {lang} is required and must be in {SUPPORTED_LANGUAGES.keys()}")
+                raise AttributeError(
+                    f"Metadata language {lang} is required and must be in {SUPPORTED_LANGUAGES.keys()}")
             p, tag_scheme = get_pipeline(
                 SUPPORTED_LANGUAGES[lang], self.cache_dir, Embeddings.xlm_roberta_base.value
             )
@@ -70,7 +95,7 @@ class TrankitNERAnnotator(AnnotatorBase):
             for sent, stext in zip(document.sentences, stexts):
                 tagged_sent = p.ner(stext, is_sent=True)
                 document.annotations.extend(
-                    tags_to_anns(tag_scheme, tagged_sent, sent.start)
+                    tags_to_anns(tag_scheme, trankit2labels, tagged_sent, sent.start)
                 )
         return documents
 
@@ -102,7 +127,7 @@ tags_parsers = {
 }
 
 
-def tags_to_anns(tag_scheme, tagged_sent, offset) -> List[Annotation]:
+def tags_to_anns(tag_scheme, trankit2labels, tagged_sent, offset) -> List[Annotation]:
     anns: List[Annotation] = []
     text = tagged_sent["text"]
     tagged_tokens = tagged_sent["tokens"]
@@ -110,14 +135,25 @@ def tags_to_anns(tag_scheme, tagged_sent, offset) -> List[Annotation]:
     func = tags_parsers[tag_scheme]
     spans = func(tags)
     for span in spans:
-        tok_start = tagged_tokens[span.start]["span"]
-        tok_end = tagged_tokens[span.end - 1]["span"]
-        ann = Annotation(
-            start=tok_start[0] + offset,
-            end=tok_end[1] + offset,
-            text=text[tok_start[0]: tok_end[1]],
-            label=span.type,
-            labelName=span.type.lower(),
-        )
-        anns.append(ann)
+        if trankit2labels is None or span.type in trankit2labels:
+            tok_start = tagged_tokens[span.start]["span"]
+            tok_end = tagged_tokens[span.end - 1]["span"]
+            if trankit2labels is None:
+                ann = Annotation(
+                    start=tok_start[0] + offset,
+                    end=tok_end[1] + offset,
+                    text=text[tok_start[0]: tok_end[1]],
+                    label=span.type,
+                    labelName=span.type.lower(),
+                )
+                anns.append(ann)
+            else:
+                for lname in trankit2labels[span.type]:
+                    ann = Annotation(
+                        start=tok_start[0] + offset,
+                        end=tok_end[1] + offset,
+                        text=text[tok_start[0]: tok_end[1]],
+                        labelName=lname
+                    )
+                    anns.append(ann)
     return anns
